@@ -470,7 +470,7 @@ spi_atk_bridget_get_dec (void)
 
   if (BONOBO_EX (&ev))
     {
-      g_warning (_("failure: no device event controller found.\n"));
+      DBG (1, g_warning (_("failure: no device event controller found.\n")));
       registry_died = TRUE;
       device_event_controller = CORBA_OBJECT_NIL;
     }
@@ -481,13 +481,7 @@ spi_atk_bridget_get_dec (void)
 int
 gtk_module_init (gint *argc, gchar **argv[])
 {
-  const gchar *load_bridge = g_getenv ("NO_AT_BRIDGE");
-
-  if (!load_bridge || atoi (load_bridge) == 0)
-    {
 	return atk_bridge_init (argc, argv);
-    }
-  return 0;
 }
 
 static void
@@ -657,16 +651,11 @@ spi_atk_bridge_exit_func (void)
 void
 gnome_accessibility_module_init (void)
 {
-  const gchar *load_bridge = g_getenv ("NO_AT_BRIDGE");
+  atk_bridge_init (NULL, NULL);
 
-  if (!load_bridge || atoi (load_bridge) == 0)
+  if (g_getenv ("AT_BRIDGE_SHUTDOWN"))
     {
-      atk_bridge_init (NULL, NULL);
-
-      if (g_getenv ("AT_SPI_DEBUG"))
-        {
-	    g_print("Atk Accessibility bridge initialized\n");
-        }
+	g_print("Atk Accessibility bridge initialized\n");
     }
 }
 
@@ -685,7 +674,7 @@ gnome_accessibility_module_shutdown (void)
   atk_bridge_initialized = FALSE;
   this_app = NULL;
 
-  if (g_getenv ("AT_SPI_DEBUG"))
+  if (g_getenv ("AT_BRIDGE_SHUTDOWN"))
     {
 	g_print("Atk Accessibility bridge shutdown\n");
     }
